==> spellathon-5.74.tar.gz: spellathon-5.74/src/logic/game.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef GAME_H
#define GAME_H

#include <string>
#include <vector>
#include <climits>

#include "defines.h"

using std::string;
using std::vector;

namespace Spellathon
{
	class Dict;

	class Game {
	public:
		Game(Dict *dct, bool plural_sieve);
		~Game() {}

		bool	play(bool precomp, int minsol, int maxsol); 
		bool	solve(string letters);
		int		solver(const char *letrs, int min = 0, int max = INT_MAX, bool need7 = true);
		void	calcScore(int nw, int nt, int h, int t, bool entered7);

		void	setPluralSieve(bool e); 
		const vector<string>& words();
		string	puzzle() const  { return puzzle_; }
		bool	pluralSieve() const { return pluralSieve_; }
		int		nWords() const { return nWords_; }
		int		score() const { return score_; }
		string	rating() const { return rating_; }

	private:
		bool	_play(int minsol, int maxsol);
		bool	_play_precomp(int minsol, int maxsol);
		int		signGen(const char *letters, char signarr[][MAX_LETRS+1]);

	private:
		Dict		*dict_;
		string		puzzle_;
		int			nWords_;
		bool		lexSort_;
		bool		pluralSieve_;
		int			score_;
		string		rating_;
		char		*wordPtrs_[SOLVER_MAX_WORDS];
		vector<string>	words_;

		Game(const Game &);
		Game & operator=(const Game &);
	};
}

#endif /* GAME_H */

==> spellathon-5.79.tar.gz: spellathon-5.79/src/logic/game.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef GAME_H
#define GAME_H

#include <string>
#include <vector>
#include <climits>

#include "defines.h"

using std::string;
using std::vector;

namespace Spellathon
{
	class Dict;

	class Game {
	public:
		Game(Dict *dct, bool plural_sieve);
		~Game() {}

		bool	play(bool precomp, int minsol, int maxsol); 
		bool	play(bool precomp, string specifiedGame); 
		bool	solve(string letters);
		int		solver(const char *letrs, int min = 0, int max = SOLVER_MAX_WORDS, bool need7 = true);
		void	calcScore(int nw, int nt, int h, int t, bool entered7);

		void	setPluralSieve(bool e); 
		const vector<string>& words();
		string	puzzle() const  { return puzzle_; }
		bool	pluralSieve() const { return pluralSieve_; }
		int		nWords() const { return nWords_; }
		int		score() const { return score_; }
		string	rating() const { return rating_; }
		string	rating_color() const { return rating_color_; }

	private:
		bool	_play(int minsol, int maxsol);
		bool	_play_precomp(int minsol, int maxsol);
		int		signGen(const char *letters, char signarr[][MAX_LETRS+1]);

	private:
		Dict		*dict_;
		string		puzzle_;
		int			nWords_;
		bool		lexSort_;
		bool		pluralSieve_;
		int			score_;
		string		rating_;
		string		rating_color_;
		char		*wordPtrs_[SOLVER_MAX_WORDS];
		vector<string>	words_;

		Game(const Game &);
		Game & operator=(const Game &);
	};
}

#endif /* GAME_H */
